LongEccDecodeError

Enum LongEccDecodeError 

pub enum LongEccDecodeError {
    BufferError(BufferError),
    FastValidate(LongEccFastValidateError),
    IntegrityCheckFailed,
    InvalidCodeword,
    HeaderDecode(LongEccHeaderFromByteSliceError),
    ReadDataError,
    ReadParityError,
    RSDecodeError(RSDecodeError),
    TryFromIntError(TryFromIntError),
}
Errors of long ECC decoding.

Variants



BufferError(BufferError)

Propagated from buffer allocation.



FastValidate(LongEccFastValidateError)

Fast validation failed



IntegrityCheckFailed

The checksum still mismatches after error correction.



InvalidCodeword

The codeword is structurally invalid.



HeaderDecode(LongEccHeaderFromByteSliceError)

Propagated from header parsing.



ReadDataError

The data bytes recorded in the header lie outside the buffer.



ReadParityError

The parity bytes recorded in the header lie outside the buffer.



RSDecodeError(RSDecodeError)

Propagated from single-codeword decoding of a segment.



TryFromIntError(TryFromIntError)

A header length field does not fit the platform’s usize.