LongEccHeaderFromBytesError

Enum LongEccHeaderFromBytesError 

pub enum LongEccHeaderFromBytesError {
    IncorrectMagic(u16),
    InvalidVersion(u8),
    IncorrectChecksum,
    CorrectionFailed(RSDecodeError),
    InvalidMessageLength(u32, u32),
    InvalidSegmentParityRatio(u8, u8),
    InvalidFullLength(u32, u64),
}
Errors returned by LongEccHeader::from_bytes.

Variants



IncorrectMagic(u16)

The magic number does not identify a long ECC header.



InvalidVersion(u8)

The encoding version is not supported.



IncorrectChecksum

The header checksum mismatches even after error correction.



CorrectionFailed(RSDecodeError)

Propagated from correcting the header bytes with the header parity.



InvalidMessageLength(u32, u32)

The header and message do not fit within the full length.



InvalidSegmentParityRatio(u8, u8)

The parity bytes leave no room for new data within a segment.



InvalidFullLength(u32, u64)

The full length does not match the codeword length derived from the message length and segment geometry.